
import React, { useRef } from 'react'
import moment from 'moment';
import { Badge, Image, DatePicker } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getList } from '@/services/work'
import PageTable from '@/components/PageTable'
import OrgSearch from '@/components/OrgSearch';

const { RangePicker } = DatePicker;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};

export default (props) => {
  const columns = [
    {
      title: '企业名称',
      dataIndex: 'orgId',
      key: 'orgId',
    },
    {
      title: '申请人',
      dataIndex: 'userName',
      key: 'userName',
    },
    {
      title: '抗原截图',
      dataIndex: 'antigenImage',
      key: 'antigenImage',
      render: t => {t?<Image src={t} width="64px" height="64px" />:''}
    },
    {
      title: '抗原结果',
      dataIndex: 'antigenIsNormal',
      key: 'antigenIsNormal',
      render: t => (
        <span>
          {t ? <Badge status="success" text="正常" /> : <Badge status="error" text="异常" />}
        </span>
      )
    },
    {
      title: '核酸截图',
      dataIndex: 'nucleicImage',
      key: 'nucleicImage',
      render: t => <Image src={t} width="64px" height="64px" />
    },
    {
      title: '核酸结果',
      dataIndex: 'nucleicIsNormal',
      key: 'nucleicIsNormal',
      render: t => (
        <span>
        {t ? <Badge status="success" text="正常" /> : <Badge status="error" text="异常" />}
        </span>
      )
    },
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => formatterTime(t),
    },
  ]


  return (
    <PageHeaderWrapper>
      <PageTable
        columns={columns}
        request={getList}
        search={false}
        options={false}
        rowKey="formId"
      />
    </PageHeaderWrapper>
  )
}
